| abbreviate | R Documentation |
Functions to abbreviate taxon names by four first letters of the generic name and four first letters of the specific epithet of a Latin name. Abbreviations may be extended by another four letters in case of infraspecific taxa. Sensu strico (s.str.) taxa are expanded by expandSensuStricto. Sensu lato (s.lat.) taxa get "slat" appended after stripping stripSensuLato.
abbreviateTaxa(x)
abbreviateSensuLato(x)
abbreviateSensuStricto(x)
abbreviateSubspecies(x)
abbreviateVariety(x)
abbreviateHybrid(x)
abbreviateAffinis(x)
abbreviateAggregate(x)
abbreviateGenus(x)
x |
a character string, or a named list of character string, in which case names(x) are used |
abbreviateSensuLato adds "slat"
abbreviateSensuStricto expands "s.str." to infraspecific given by species epithet.
abbreviateSubspecies drops ssp.
abbreviateVariety drops var.
abbreviateHybrid not implemented yet
abbreviateAffinis not implemented yet
abbreviateGenus adds "spec ies", this tries to ensure ambiguous abbreviations for taxa like Galeopsis speciosa.
character.
Roland Kaiser
make.cepnames in vegan
# Nothing here yet
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.