| is | R Documentation |
Functions to test character strings for belonging to specific cases used in scientific binomials, including intra specific taxa, determination ambiguities and depth.
isWhat(x)
isResolved(x)
isSensuLato(x)
isSensuStricto(x)
isSensuStrictoSubspecies(x)
isSubspecies(x)
isVariety(x)
isSensuStrictoVariety(x)
isHybrid(x)
isAffinis(x)
isAggregate(x)
isGenus(x)
x |
a character string, or a named list of character string, in which case names(x) are used |
isWhat applies all the below listed (sub-)functions in a single step.
isResolved applies isWhat but returns only elements where isResolved is TRUE.
isSensuLato test for sensu lato (s.lat.) taxon.
isSensuStricto test for sensu strico (s.str.) taxon (nominotypical form).
isSensuStrictoSubspecies test subspecies epithet if it is the nominotypical form.
isSubspecies test for subspecies.
isVariety test for variety.
isSensuVariety test variety epithet if it is the nominotypical form.
isHybrid test for Hybrid combination.
isAffinis test for being ambiguously identified.
isAggregate test for species aggregate.
isGenus test for determination only at genus level (Genus sp.).
Calling functions without argument returns the strings searched by each function.
logical.
Roland Kaiser
stripAll
x <- c(
"Thalictrum simplex s.lat.",
"Thalictrum simplex s.str.",
"Thalictrum simplex ssp. simplex",
"Thalictrum simplex ssp. galioides",
"Quercus pubescens ssp. pubescens",
"Abietinella abietina var. abietina",
"Mentha \u00D7 dumetorum", # MULTIPLICATION SIGN (U+00D7) \u00D7
"Mentha x dumetorum", # standard x gylph as multiplication sign
"Mentha cf. arvensis",
"Achillea millefolium agg.",
"Bellis perennis")
isWhat(taxa)
isResolved(taxa)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.