| linktaxa | R Documentation |
A single function internally calling subroutines and returning an ordered data frame of string matches or writes these results to a csv file.
linktaxa(x, y, order = TRUE, file, sep = ",", overwrite = FALSE, ...)
x |
|
y |
|
order |
|
file |
|
sep |
|
overwrite |
|
... |
arguments passed to |
If order is TRUE results are ordered according to penalty score, if FASLE input order of x is retained.
a data.frame.
Roland Kaiser s
isWhat, stripAll
data(taxa)
res <- linktaxa(taxa, reference)
head(res[, 1:3])
tail(res[, 1:3])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.