| seek | R Documentation |
Search for strings using fuzzy matching.
seekTaxon(x, y, max.distance = 0.3, strip = TRUE, exact = TRUE)
seekTaxa(x, y, max.distance = 0.3, strip = TRUE, exact = TRUE)
x |
a character. |
y |
a character to be compared to argument |
max.distance |
see |
strip |
if |
exact |
if a single exact match are is found, retain only this. |
The algorithm proceeds as follows:
Seek matches with agrep and max.distance = 0.05.
If search is empty use dropIntraspecific followed by subsequent calls to asSensuStricto if necessary.
If all these still return no match (the taxon of question might be missing in y) relax string distance to return at least something similar (argument max.distance).
Finally order matches based on stringdist in package stringdist.
If taxon is Genus sp. it has to match precisely.
a named list of approximate matches for each element of argument x retained as list names.
Roland Kaiser
judgePenalty
seekTaxon("Leontodon", reference)
seekTaxa(taxa, reference)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.